Openwillis is a python library for digital measurement of health.

It was developed by Brooklyn Health to establish standardized methods in digital measurement.

It is free for non-commercial use ([see license](https://github.com/bklynhlth/openwillis/blob/main/LICENSE.txt)).

* [Official website](https://www.bklynhlth.com/openwillis)
* [Documentation](https://github.com/bklynhlth/openwillis/wiki)
* [Getting started](https://github.com/bklynhlth/openwillis/wiki/1.-Getting-started)
* [List of functions](https://github.com/bklynhlth/openwillis/wiki/2.-List-of-functions)
* [Research guidelines](https://github.com/bklynhlth/openwillis/wiki/3.-Research-guidelines)

Please report any issues using the [Issues](https://github.com/bklynhlth/openwillis/issues) tab or get in touch through openwillis@bklynhlth.com.
